/*-------------------------------------------------------------------------*
 * BBS.CMD                                                                 *
 *                                                                         *
 * Rexx procedure to govern execution of BinkleyTerm and BBS operations.   *
 *-------------------------------------------------------------------------*/

echo off

cls

call "c:\environ"           /* set up environment */

got_packets = 0

do forever

    setcolor green black "-h"   /* choose a color scheme to easily identify */
                                /* the BBS session */
    /*
     * Get rid of any errant *.BSY files!  Since this is only a one-line
     * system, there should not be any Busy files for nodes.  If there
     * are, it would indicate a crash of some sort while Binkley was
     * connected to another system.
     */

    del "c:\binkley\inbound\*.bsy > nul: 2>&1"
    del "c:\binkley\ibmnet.028\*.bsy > nul: 2>&1"
    del "c:\binkley\os2net.051\*.bsy > nul: 2>&1"

    /*
     * Restart any failed connects/transfers at the beginning.
     */

    del "c:\binkley\inbound\badwazoo.* > nul: 2>&1"

    /*
     * Pre-binkley checks and setups
     */

    call setports               /* set baud, etc. on comm ports */

    /*
     * Start binkley and process return code
     */

    "c:"                        /* Get to the drive and binkley directory */
    cd "\bbs\binkley"

    call bbslog "bbs", "Initiating BinkleyTerm"

    rc = 255                    /* Default error if OS/2 cannot start BTP */

    BTP NoForce Dynam Share Unattended

    select
        when rc = 255 then      /* Error: internal error */
            call bbslog "bbs", "Internal error"

        when rc = 254 then      /* Error: address not found in nodelist */
            do
            call bbslog "bbs", "Address not found in nodelist"
            exit
            end

        when rc = 200 then      /* Call for Quotes */
            do
            call bbslog "bbs", "Calling for Quotes Begin"
            call GetQuotes
            call bbslog "bbs", "Calling for Quotes End"
            end

        when rc = 192 then      /* 19200 bps Non-Mail call */
            call bbslog "bbs", "BBS exit not support -- should spawn, exit code =", rc

        when rc = 128 then      /* 38400 bps Non-Mail call */
            call bbslog "bbs", "BBS exit not support -- should spawn, exit code =", rc

        when rc = 100 then      /* F10 keypress */
            call bbslog "bbs", "F10 keypress"

        when rc =  99 then      /* External mail string - MAILBAT.CMD */
            call bbslog "bbs", "External mail string detected"

        when rc =  96 then      /* 9600 bps Non-Mail call */
            call bbslog "bbs", "BBS exit not support -- should spawn, exit code =", rc

        when rc =  90 then      /* F9 keypress */
            call bbslog "bbs", "F9 keypress"

        when rc =  80 then      /* F8 keypress */
            call bbslog "bbs", "F8 keypress"

        when rc =  70 then      /* F7 keypress */
            call bbslog "bbs", "F7 keypress"

        when rc =  60 then      /* F6 keypress */
            call bbslog "bbs", "F6 keypress"

        when rc =  54 then      /* 19200 bps */
            call bbslog "bbs", "19200 bps, exit code =", rc

        when rc =  50 then      /* F5 keypress */
            call bbslog "bbs", "F5 keypress"

        when rc =  48 then      /* 4800 bps Non-Mail call */
            call bbslog "bbs", "BBS exit not support -- should spawn, exit code =", rc

        when rc =  40 then      /* F4 keypress */
            call bbslog "bbs", "F4 keypress"

        when rc =  30 then      /* Incoming compressed mail and F3 keypress */
            do
            call bbslog "bbs", "Incoming compressed mail (or F3 keypress)"
            call IncomingMail
            end

        when rc =  24 then      /* 2400 bps Non-Mail call */
            call bbslog "bbs", "BBS exit not support -- should spawn, exit code =", rc

        when rc =  21 then      /* OS2NET Poll -- 81:202/1 */
            do
            call bbslog "bbs", "OS2NET Poll"
            del "c:\binkley\os2net.051\00ca0001.$$* > nul: 2>&1"
            create "c:\binkley\os2net.051\00ca0001.clo"
            end

        when rc =  20 then      /* Incoming (non-compressed) mail and F2 keypress */
            do
            call bbslog "bbs", "Incoming (mon-compressed) mail (or F2 keypress)"
            call IncomingMail
            end

        when rc =  19 then      /* Fernwood Poll -- 1:153/920 */
            do
            call bbslog "bbs", "Fernwood Poll"
            /*
            del "c:\binkley\outbound\008d00d1.$$* > nul: 2>&1"
            create "c:\binkley\outbound\008d00d1.clo"
            */

            del "c:\binkley\outbound\00990398.$$* > nul: 2>&1"
            create "c:\binkley\outbound\00990398.clo"
            end

        when rc =  18 then      /* Monthly Maintenance */
            do
            call bbslog "bbs", "Monthly Maintenance"
            call MonthlyMaint
            end

        when rc =  17 then      /* Weekly Maintenance */
            do
            call bbslog "bbs", "Weekly Maintenance"
            call WeeklyMaint
            end

        when rc =  16 then      /* Poll 1:170/202 -- Steve Dressler's board */
            do
            /*
             * Re-start any failed local connects for Net 170.
             */

            del "c:\binkley\outbound\00aa*.$$* > nul: 2>&1"

            /*
            call bbslog "bbs", "Polling For TTALK"
            del "c:\binkley\outbound\00aa00ca.$$* > nul: 2>&1"
            create "c:\binkley\outbound\00aa00ca.clo"
            */
            end

        when rc =  15 then      /* Midnight Processing */
            do
            call bbslog "bbs", "Midnight Processing"
            call MidnightProcessing
            end

        when rc =  14 then      /* Daily/Nightly maintenance routine */
            do
            call bbslog "bbs", "Nightly Maintenance"
            call NightlyMaint
            end

        when rc =  13 then      /* Process any nodelist changes for ibmNET */
            do
            /*
            call bbslog "bbs", "Process update ibmNET nodelist file"
            call ibmupd.cmd
            */
            end

        when rc =  12 then      /* 1200 bps Non-Mail call */
            call bbslog "bbs", "BBS exit not support -- should spawn, exit code =", rc

        when rc =  10 then      /* F1 keypress */
            call bbslog "bbs", "F1 keypress"

        when rc =   3 then      /* 300 bps Non-Mail call */
            call bbslog "bbs", "BBS exit not support -- should spawn, exit code =", rc

        when rc =   1 then      /* Alt-X exit */
            do
            call bbslog "bbs", "Alt-X exit -- Binkley terminating"
            setcolor green black "-h"   /* choose a color scheme to easily identify */
                                        /* the BBS session */
            exit
            end

        otherwise
            call bbslog "bbs", "Unknown exit code from BinkleyTerm (", rc, ")"
    end     /* select */

end     /* forever loop */

/*-------------------------------------------------------------------------*
 * Subroutines                                                             *
 *-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------*
 * MidnightProcessing                                                      *
 *                                                                         *
 * Perform any duties that should occur at the beginning of the day.       *
 *-------------------------------------------------------------------------*/

MidnightProcessing:

    /*
     * Re-start any failed local connects for Net 170
     */

    del "c:\binkley\outbound\00aa*.$$* > nul: 2>&1"

    /*
     * Re-start any failed local connects for ibmNET, Net 4372
     */

    del "c:\binkley\ibmnet.028\1114*.$$* > nul: 2>&1"

    /*
     * First, create statistic information from log file and then
     * archive the log files
     */

    "c:"
    cd "\bbs\stat"

    copy "c:\bbs\max\system\max01.log  max01.log"
    copy "c:\bbs\logs\binkley.log      binkley.log"
    
    MaxLog

    /*
     * Scan log files for errors and mail me the errors if any are
     * found.
     */

    mailerrs "c:\bbs\logs\*.log, c:\bbs\max\system\max01.log >> c:\bbs\logs\mailerrs.out 2>&1"

    call pvtlocal

    /*
     * Tell VDM server to close log file and rename it to *.bak
     */

    call RunDOS RefreshLog '/Wait /WaitTimeout=10'
    copy 'c:\bbs\logs\vdmserve.bak c:\bbs\logs\vdm.log'

    /*
     * Archive log files for the day, and rename today's copies *.bak
     */

    "c:"
    cd "\bbs\logs"

    copy 'pvtscan.log pvtscan.bak'
    del 'pvtscan.log'
    copy 'doscmd.log doscmd.bak'
    del 'doscmd.log'

    LogSave "c:\bbs\logs\logs.zip /logfiles=(c:\bbs\max\system\max01.log,binkley.log,bbs.log,tick.log,fan.log,msgx.log,truedate.log,fmpatch.log,filemgr.log,netscan.log,vdm.log) /kill/noquiet/backup > \bbs\logs\logsave.out 2>&1"

    return(0)

/*-------------------------------------------------------------------------*
 * NightlyMaint                                                            *
 *                                                                         *
 * Perform daily maintenance.  Triggered by binkley event exit code 14.    *
 *-------------------------------------------------------------------------*/

NightlyMaint:

    call maint.cmd
    
    return(0)

/*-------------------------------------------------------------------------*
 * WeeklyMaint                                                             *
 *                                                                         *
 * Perform weekly maintenance.  Triggered by binkley event exit code 17.   *
 *-------------------------------------------------------------------------*/

WeeklyMaint:

    detach weekly "> c:\bbs\logs\weekly.out 2>&1"

    return(0)

/*-------------------------------------------------------------------------*
 * MonthlyMaint                                                            *
 *                                                                         *
 * Perform monthly maintenance.  Triggered by binkley event exit code 18.  *
 *-------------------------------------------------------------------------*/

MonthlyMaint:

    call userbase.cmd

    detach monthly "> c:\bbs\logs\monthly.out 2>&1"

    return(0)

/*-------------------------------------------------------------------------*
 * IncomingMail                                                            *
 *                                                                         *
 * Incoming mail detected from binkley.  Process compressed and            *
 * un-compressed mail.  Distribute to all message areas.                   *
 *-------------------------------------------------------------------------*/

IncomingMail:

    detach import "> c:\bbs\logs\import.out 2>&1"

    return(0)

/*-------------------------------------------------------------------------*
 * GetQuotes                                                               *
 *                                                                         *
 * Get Quotes for the week.                                                *
 *-------------------------------------------------------------------------*/

GetQuotes:

    call qc_daily_collect

    return(0)
