/*-------------------------------------------------------------------------*
 * EXPORT.CMD                                                              *
 *                                                                         *
 * Rexx procedure to export EchoMail.                                      *
 *-------------------------------------------------------------------------*/

echo off

/*
 * Check to see if tag file exists, if it does, then exit.
 *
 * We do not want to collide with an IMPORT -- wait till it is done
 * and then lock out IMPORT until this EXPORT is done.
 */

status = CheckTag( "c:\bbs\logs\mail.tag" )

if status = 1 then
    do
    echo "Mail processing already in progress, cannot start another mail process now."
    call bbslog "Export", "Export attempted while mail processing in progress"
    exit            /* get out */
    end

/*
 * Begin Export process
 */

call bbslog "Export", "Exporting mail"

/*
 * Set "sent" bit on private local mail
 */

call pvtlocal

netscan

"c:"
cd "\binkley\outbound"

rc = isfile( "c:\bbs\logs\echotoss.log" )

if ( rc > 0 ) then
    squish OUT SQUASH "-fc:\bbs\logs\echotoss.log"
else
    squish OUT SQUASH

select
    when rc = 0 then                        /* nothing Exported */
        call bbslog "Export", "NO files found to Export"

    when rc = 1 then                        /* fatal error */
        do
        call bbslog "Export", "Fatal Error from SQUISH while Exporting mail"
        del "c:\bbs\logs\mail.tag"          /* remove tag file */
        exit
        end

    when rc = 2 then                        /* Exported EchoMail */
        call bbslog "Export", "EchoMail found to Export"

    when rc = 3 then                        /* Imported NetMail */
        call bbslog "Export", "NetMail found to Import"

    when rc = 4 then                        /* Imported NetMail and EchoMail */
        call bbslog "Export", "NetMail/EchoMail found to Import"

    when rc = 5 then                        /* reached MaxMsgs */
        call bbslog "Export", "Reached MaxMsgs"

    otherwise
        call bbslog "Export", "Unknown return code" rc "from SQUISH"
end

/*
 * Update Maximus message database files for any *.MSG areas
 */

scanbld "c:\bbs\max\system\user.bbs c:\bbs\max\system\area.dat local matrix echo"

del "c:\bbs\logs\mail.tag"          /* remove tag file */

del "c:\bbs\logs\echotoss.log"      /* remove echotoss file if exists */

call bbslog "Export", "Export complete"

exit
