/*-------------------------------------------------------------------------*
 * IMPORT.CMD                                                              *
 *                                                                         *
 * Rexx procedure to import EchoMail.                                      *
 *-------------------------------------------------------------------------*/

echo off

cls

/*
 * Check to see if tag file exists, if it does, then exit.
 */

status = CheckTag( 'c:\bbs\logs\mail.tag' )

if status = 1 then
    do
    echo 'Mail processing already in progress, cannot start another mail process now.'
    call bbslog 'Import', 'Import attempted while mail processing in progress'
    exit            /* get out */
    end

/* outputfilename = 'c:\bbs\logs\import.out' */
outputfilename = 'nul:'

echo 'Importing mail at' date() time() '>>' outputfilename

call bbslog 'Import', 'Importing mail'

/*
 * When testing, first save anything in the INBOUND directory
 */

/* copy 'c:\binkley\inbound\f175*.* c:\binkley\inbound\save' */
/* copy 'c:\binkley\inbound\7c0e*.* c:\binkley\inbound\save' */
/* copy 'c:\binkley\inbound\*.* c:\binkley\inbound\save' */
copy 'c:\binkley\inbound\*.pkt c:\binkley\inbound\save'

/*
 * Set 'sent' bit on private local mail
 */

call pvtlocal

/*
 * Copy any FidoNet newsletter files to downloadable file area and update
 * FILES.BBS.
 */

rc = isfile( 'c:\binkley\inbound\fnews*.*' )

if ( rc > 0 ) then
    do

    'c:'
    cd '\binkley\inbound'

    truedate 'fnews*.* /quiet'

    for '%%x in (fnews*.*) do echo %%x Weekly FidoNet Newsletter >> c:\max\files\news\files.bbs'

    copy 'FNEWS*.* c:\max\files\news > nul: 2>&1'
    del 'FNEWS*.* > nul: 2>&1'

    end

/*
 * Check to see if there are any nodelist files in -- If so, process and
 * create new nodelists
 */

call nodelist

/*
 * Check to see if we got a new AVB listing.  If so, move it to the
 * bulletin directory.
 */

call postAVB

/*
 * Check to see if we got any FILES list in.
 */

call checklst

/*
 * Check to see if any of our file-requests have been satisfied
 */

call checkreq

/*
 * Process any *.TIC files that have come in
 */

call scantics

/*
 * Call Squish to uncompress any compressed mail bundles and process the
 * mail packets.
 */

got_netmail = 0

'c:'
cd '\binkley\inbound'

squish IN OUT SQUASH

select
    when rc = 0 then                        /* nothing imported */
        do
        echo 'Nothing Imported! >>' outputfilename
        call bbslog 'Import', 'NO files found to Import'
        del 'c:\bbs\logs\mail.tag'          /* remove tag file */
        exit
        end

    when rc = 1 then                        /* fatal error */
        do
        del 'c:\bbs\logs\mail.tag'          /* remove tag file */
        call bbslog 'Import', 'Fatal Error from SQUISH while Importing mail'
        exit
        end

    when rc = 2 then                        /* Exported EchoMail */
        call bbslog 'Import', 'EchoMail found to Export'

    when rc = 3 then                        /* Imported NetMail */
        do
        call bbslog 'Import', 'NetMail found to Import'
        got_netmail = 1;
        end

    when rc = 4 then                        /* Imported NetMail and EchoMail */
        do
        call bbslog 'Import', 'NetMail/EchoMail found to Import'
        got_netmail = 1;
        end

    when rc = 5 then                        /* reached MaxMsgs */
        call bbslog 'Import', 'Reached MaxMsgs'

    otherwise
        call bbslog 'Import', 'Unknown return code' rc 'from SQUISH'
end

/*
 * Scan any new netmail to me to the private folder
 */

netscan '/noout'

/*
 * If we got NetMail, have FileMgr and SEAL take a look in the
 * Netmail directory to see if they were for it.
 */

if got_netmail > 0 then
    do
    /*
     * Scan NetMail for any FAN registrations
     */

    'c:'
    cd '\bbs\fan'
    fanscan '/config=c:\bbs\fan\fan.cfg > nul: 2>&1'

    /*
     * Check for any incoming SEAL messages
     */

    'c:'
    cd '\bbs\seal'

    call RunDOS 'runseal.bat' '/Wait /WaitTimeout=120'

    /*
     * Check to see if rescan file was created by SEAL
     */

    rc = isfile( 'c:\bbs\squish\sqrescan.bat' )

    if rc > 0 then
        do
        call CreateRescanFile
        call sqrescan.cmd
        end

    /*
     * Run Squish again to process any messages that might have been
     * created by SEAL.
     */

    squish IN OUT SQUASH

    end

/*
 * Update Maximus message database files.
 *
 * Always update local and matrix areas, update echos areas found in
 * ECHOTOSS.LOG.  Delete the log after done.  NOTE: since most areas are
 * now Squish -- SCANBLD is only necessary for any areas that are still
 * *.MSG format.
 */

call bbslog 'Import', 'Updating Maximus area database files'

scanbld 'c:\bbs\max\system\user.bbs c:\bbs\max\system\area.dat local matrix @c:\bbs\logs\echotoss.log -c'

del 'c:\bbs\logs\mail.tag'        /* remove tag file */

call bbslog 'Import', 'Import complete'

exit


/*-------------------------------------------------------------------------*
 * CreateRescanFile                                                        *
 *                                                                         *
 * Convert the SEAL rescan .BAT file to a .CMD file, but ignore certain    *
 * echos for rescan such as LOCAL since it contains private messages.      *
 *                                                                         *
 *-------------------------------------------------------------------------*/

CreateRescanFile:

    'c:'
    'cd \bbs\squish'

    batfile = 'C:\BBS\SQUISH\SQRESCAN.BAT'
    cmdfile = 'C:\BBS\SQUISH\SQRESCAN.CMD'

    del cmdfile     /* delete any old .CMD file if it exists */

    status = stream( batfile, 'c', 'open read' )
    status = stream( cmdfile, 'c', 'open write' )

    do forever
        linestr = linein( batfile )         /* read in a line */

        parse upper var linestr linestr

        if linestr = "" then
            leave                           /* all done reading file */

        if pos( 'LOCAL', linestr ) = 0 then
            status = lineout( cmdfile, linestr )
    end

    status = stream( batfile, 'c', 'close' )
    status = stream( cmdfile, 'c', 'close' )

    del batfile     /* delete the original .BAT */

return(1)
