/*-------------------------------------------------------------------------*
 * MAKELIST.CMD                                                            *
 *                                                                         *
 * Rexx procedure to create 170-110.LST and update each FILES.BBS in       *
 * download directories.                                                   *
 *-------------------------------------------------------------------------*/

echo off

cls

call bbslog "makelist", "File Lists Creation Started"

"c:"
cd "\bbs\downsort"

/*
 * Create DOWN_ALL.A~A, rename to 170-110.LST, compress it to
 * 170-110.ZIP, and put it in the "LiveNet related files" directory.
 *
 * File c:\bbs\downsort\170-110.zip will be sent for FILES requests
 * File c:\max\files\livenet\allfiles.zip is for BBS downloaders
 */

downsort "-x"

del "170-110.LST > nul: 2>&1"
del "170-110.ZIP > nul: 2>&1"

del "170-110.NEW > nul: 2>&1"
del "170-110N.ZIP > nul: 2>&1"

del "ALLFILES.ZIP > nul: 2>&1"
del "LiveNet.lst > nul: 2>&1"

/*
 * Update my BinkleyTerm OKFILES Freq list
 */

copy "down_ok.o~a c:\bbs\binkley\okfiles.txt"

/*
 * Make 170-110.lst for the FILES request (usually Sysops of other systems)
 */

copy "c:\bbs\binkley\about.txt LiveNet.Txt"

rc = isfile( "down_all.a~a" )

if rc <= 0 then
    do
    call bbslog "makelist", "No list file found"
    exit
    end

rename "down_all.a~a 170-110.LST"
pkzip "170-110.ZIP 170-110.LST LiveNet.Txt"

/*
 * Make 170-110N.lst for the NEW request (usually Sysops of other systems)
 */

copy "c:\bbs\binkley\about.txt LiveNet.Txt"

rc = isfile( "down_new.n~a" )

if rc <= 0 then
    do
    call bbslog "makelist", "No list file found"
    exit
    end

rename "down_new.n~a 170-110.NEW"
pkzip "170-110N.ZIP 170-110.NEW LiveNet.Txt"
copy "170-110N.ZIP c:\max\files\livenet\newfiles.zip"

/*
 * Make LIVENET.LST and ALLFILES.ZIP for the users
 */

rename "170-110.lst LiveNet.lst"
pkzip "allfiles.zip LiveNet.lst LiveNet.Txt"
copy "allfiles.zip c:\max\files\livenet\allfiles.zip"
del allfiles.zip

/*
 * Update each FILES.BBS
 */

call SetFilesBBS c, 10, "livenet"
call SetFilesBBS d, 11, "echos"
call SetFilesBBS c, 12, "news"
call SetFilesBBS c, 13, "misc"
call SetFilesBBS c, 14, "max"
call SetFilesBBS c, 15, "binkley"
call SetFilesBBS c, 16, "fidonet"
call SetFilesBBS c, 17, "c"
call SetFilesBBS c, 18, "os2\internet"

call SetFilesBBS c, 96, "fwadmin"
call SetFilesBBS c, 98, "os2new"
call SetFilesBBS c, 99, "newup"

call SetFilesBBS c, 21, "os2\fonts"
call SetFilesBBS c, 22, "os2\rexx"
call SetFilesBBS d, 23, "os2\gnu"
call SetFilesBBS c, 24, "graphics"
call SetFilesBBS c, 25, "sio"

call SetFilesBBS d, 30, "os2\app"
call SetFilesBBS c, 31, "os2\util"
call SetFilesBBS c, 32, "os2\misc"
call SetFilesBBS c, 34, "os2\edit"
call SetFilesBBS c, 35, "os2\file"
call SetFilesBBS c, 36, "os2\games"
call SetFilesBBS c, 37, "os2\archive"
call SetFilesBBS c, 38, "os2\prog"
call SetFilesBBS c, 40, "os2\bbs"
call SetFilesBBS c, 41, "os2\mag"

call SetFilesBBS c, 50, "os20\app"
call SetFilesBBS c, 51, "os20\util"
call SetFilesBBS c, 52, "os20\misc"
call SetFilesBBS c, 53, "os20\drivers"
call SetFilesBBS c, 54, "os20\edit"
call SetFilesBBS c, 55, "os20\file"
call SetFilesBBS c, 56, "os20\games"
call SetFilesBBS c, 57, "os20\archive"
call SetFilesBBS c, 58, "os20\prog"
call SetFilesBBS c, 59, "os20\comm"
call SetFilesBBS c, 60, "os20\bbs"
call SetFilesBBS c, 61, "os20\mag"
call SetFilesBBS c, 62, "os20\lan"
call SetFilesBBS c, 63, "os20\install"
call SetFilesBBS c, 64, "os20\articles"
call SetFilesBBS c, 65, "os20\wps"
call SetFilesBBS d, 66, "os2\mm"

call SetFilesBBS c, 70, "msdos\bbs"
call SetFilesBBS c, 71, "msdos\comm"
call SetFilesBBS c, 72, "msdos\util"
call SetFilesBBS c, 73, "msdos\misc"
/* call SetFilesBBS c, 74, "msdos\apg" */
/* call SetFilesBBS c, 75, "msdos\games" */

call SetFilesBBS d, 80, "ibmnet\info"
call SetFilesBBS d, 81, "ibmnet\os2fx"
call SetFilesBBS d, 82, "ibmnet\dosfx"
call SetFilesBBS d, 83, "ibmnet\tcpip"
call SetFilesBBS d, 84, "ibmnet\ews"
call SetFilesBBS d, 85, "ibmnet\lexmark"
call SetFilesBBS d, 86, "ibmnet\beta"
call SetFilesBBS d, 97, "ibmnet\ibmnet"

/* call SetFilesBBS c, PV,  "private" */


call bbslog "makelist", "File Lists Creation Finished"

Exit

/*-------------------------------------------------------------------------*
 * SetFilesBBS                                                             *
 *                                                                         *
 * Copy old FILES.BBS to FILES.BAK and replace FILES.BBS with new sorted   *
 * FILES.nnn.                                                              *
 *                                                                         *
 * Arg(1) : Drive letter for the file directory                            *
 * Arg(2) : Number of file area                                            *
 * Arg(3) : Directory name of file area (partial -- not full)              *
 *                                                                         *
 *-------------------------------------------------------------------------*/

SetFilesBBS:

    drive = arg(1)
    areanum = arg(2)
    dirname = arg(3)

    /*
     * Copy old files.bbs to files.bak in 'files directory'.
     */

    copy drive":\max\files\"dirname"\files.bbs" drive":\max\files\"dirname"\files.bak"

    /*
     * Copy downsort FILES.nnn to 'files directory'
     */

    "c:"
    cd "\bbs\downsort\filesbbs"
    copy "files."areanum drive":\max\files\"dirname"\files.bbs"
    del "files."areanum

    return(0)
