/*-------------------------------------------------------------------------*
 * NODELIST.CMD                                                            *
 *                                                                         *
 * Rexx procedure to update and/or create all nodelist files.              *
 *                                                                         *
 * Arg(1) : If "force", then all nodelists will be re-compiled regardless  *
 *          if new nodediffs/nodelists are in the inbound directory.       *
 *                                                                         *
 *-------------------------------------------------------------------------*/

"@echo off"

/* trace results */

/*-------------------------------------------------------------------------*
 * Declare global variables                                                *
 *-------------------------------------------------------------------------*/

call RxFuncAdd 'SysFileTree', 'RexxUtil', 'SysFileTree'

donelistfile    = "c:\bbs\nodelist\done.lst"

inbounddir      = "c:\binkley\inbound"
fastlistdir     = "c:\bbs\fastlist"

/*
 * Since we use the MOVE command for the two following paths, we cannot
 * have a drive specification in them since MOVE will not move files
 * across drives.  (Brain dead program....)
 */

nodelistdir     = "\bbs\nodelist"
workdir         = "\bbs\nodelist\work"

FALSE = 0
TRUE  = 1

/*-------------------------------------------------------------------------*
 * MainLine                                                                *
 *-------------------------------------------------------------------------*/

if arg(1) = "force" then
    force_compile = TRUE
else
    force_compile = FALSE

/*
 * Change to drive which have 'nodelistdir' and 'workdir' directories
 */

"c:"

/*
 * Copy nodediff to specified point systems if it exists
 */

filename = inbounddir'\nodediff.a*'

CALL SysFileTree filename, 'file', 'FO', '*****'

if file.0 > 0 then
    do
    del 'c:\bbs\nodelist\save\nodediff.a*'
    copy filename 'c:\bbs\nodelist\save'

    /* send to 170/110.601 */
    echo 'c:\bbs\nodelist\save\'FILESPEC("name",file.1) '>> c:\binkley\outbound\00aa006e.pnt\00000259.hlo'

    /* send to 170/110.12 */
    echo 'c:\bbs\nodelist\save\'FILESPEC("name",file.1) '>> c:\binkley\outbound\00aa006e.pnt\0000000c.hlo'
    end


/*
 * Process FidoNet nodelist/nodediff
 */

cnt = 0

cnt = cnt + UncompressNodelist( "nodediff.a*", "arc xo", TRUE )
cnt = cnt + UncompressNodelist( "nodelist.a*", "arc xo", TRUE )

if (cnt > 0) | (force_compile = TRUE) | (arg(1) = "fidonet") then
    status = CompileNodelist( "node", "fidonet.cfg" )

/*
 * Process ibmNET nodelist/nodediff
 */

cnt = 0

cnt = cnt + UncompressNodelist( "ibmdiff.z*"  "pkunzip -o", FALSE )
cnt = cnt + UncompressNodelist( "ibmlist.z*", "pkunzip -o", FALSE )

if (cnt > 0) | (force_compile = TRUE) | (arg(1) = "ibmnet") then
    status = CompileNodelist( "ibm", "ibmnet.cfg" )

/*
 * Process OS2NET nodelist/nodediff
 */

cnt = 0

cnt = cnt + UncompressNodelist( "os2diff.z*", "pkunzip -o", FALSE )
cnt = cnt + UncompressNodelist( "os2list.z*", "pkunzip -o", FALSE )

if (cnt > 0) | (force_compile = TRUE) | (arg(1) = "os2net") then
    status = CompileNodelist( "os2", "os2net.cfg" )

/*
 * Process ZyXELNet nodelist/nodediff
 */

cnt = 0

cnt = cnt + UncompressNodelist( "zyx_net.a*", "arc xo", TRUE )

/*
 * Patch for brain-dead nonstandard file naming convention for ZyXELNet
 */

cd workdir
rename 'zyx_net.* z18-list.*'

/*
cnt = cnt + UncompressNodelist( "zyx_diff.a*", "arc xo", TRUE )
*/

/*
cnt = cnt + MoveNodelist( "z18-diff.*", TRUE )
cnt = cnt + MoveNodelist( "z18-list.*", TRUE )
*/

if (cnt > 0) | (force_compile = TRUE) | (arg(1) = "zyxel") then
    status = CompileNodelist( "z18-", "zyxelnet.cfg" )

cd fastlistdir

exit

/*-------------------------------------------------------------------------*
 * CompileNodelist                                                         *
 *                                                                         *
 * Compile the nodelist                                                    *
 *                                                                         *
 * Arg(1) : Prefix for the nodelist                                        *
 * Arg(2) : Configuration file for FastLst                                 *
 *                                                                         *
 *-------------------------------------------------------------------------*/

CompileNodelist:

    prefix = arg(1)
    configfilename = fastlistdir'\'arg(2)

    nodelist = prefix"list"
    nodediff = prefix"diff"

    call bbslog "NodeList", "Compiling" nodelist "using" configfilename

    /*
     * Note:   'nodelistdir' and 'workdir' must be on the same drive for
     *         the MOVE command to work correctly.
     */

    cd workdir

    fastlistdir"\"fastlst "-c"configfilename "-n"nodelist "-d"nodediff "-l"fastlistdir"\fastlist.log"

    if rc > 0 then
        do
        call bbslog "NodeList", "Error code" rc "from FastLst"
        return(FALSE)
        end

    del nodelistdir"\"prefix"x.dat > nul: 2>&1"
    move "nodex.dat" nodelistdir"\"prefix"x.dat"

    del nodelistdir"\"prefix"x.ndx > nul: 2>&1"
    move "nodex.ndx" nodelistdir"\"prefix"x.ndx"

    if nodelist = "nodelist" then
        do
        /*
         * If we just compiled FidoNet's nodelist, move the SYSOP index
         * file also.
         */
        del nodelistdir"\sysop.ndx > nul: 2>&1"
        move "sysop.ndx" nodelistdir"\sysop.ndx"
        end

return(TRUE)

/*-------------------------------------------------------------------------*
 * MoveNodelist                                                            *
 *                                                                         *
 * Move the list to the nodelist WORK directory.                           *
 *                                                                         *
 * Arg(1) : Name of NODELIST/NODEDIFF file                                 *
 * Arg(2) : TRUE=delete nodelist in the inbound directory, FALSE=keep it   *
 *                                                                         *
 * This routine is for nodelists that come which are already uncompressed. *
 *                                                                         * 
 *-------------------------------------------------------------------------*/

MoveNodelist:

    filename        = inbounddir'\'arg(1)
    delete_file     = arg(2)

    fcnt = 0

    cd workdir

    /*
     * Get list of files
     */

    CALL SysFileTree filename, 'file', 'FO', '*****'

    do i = 1 to file.0

        if IsInList( file.i ) = FALSE then
            do
            call bbslog "NodeList", "Moving" file.i
            copy file.i workdir
            /* add filename to "done list" */
            echo file.i">>"donelistfile
            fcnt = fcnt + 1
            if delete_file = TRUE then
                del file.i  /* delete file from inbound directory */
            end

    end

return( fcnt )


/*-------------------------------------------------------------------------*
 * UncompressNodelist                                                      *
 *                                                                         *
 * Uncompress the list to the nodelist WORK directory.                     *
 *                                                                         *
 * Arg(1) : Name of NODELIST/NODEDIFF file                                 *
 * Arg(2) : Command line to execute unarchive program                      *
 * Arg(3) : TRUE=delete nodelist archive after unarc, FALSE=keep it        *
 *                                                                         *
 * The file will only be unarced if it does NOT exist in the "done list"   *
 * file.                                                                   *
 *                                                                         *
 * This list file should be checked since there are times when TIC does    *
 * not toss the incoming nodelist/nodediff from the inbound directory and  *
 * it will just sit there until I do something about it manually.          *
 *                                                                         * 
 *-------------------------------------------------------------------------*/

UncompressNodelist:

    filename        = inbounddir'\'arg(1)
    unarc_command   = arg(2)
    delete_file     = arg(3)

    fcnt = 0

    cd workdir

    /*
     * Get list of files
     */

    CALL SysFileTree filename, 'file', 'FO', '*****'

    do i = 1 to file.0

        if IsInList( file.i ) = FALSE then
            do
            call bbslog "NodeList", "Uncompressing" file.i
            unarc_command file.i
            if rc > 0 then
                do
                call bbslog "NodeList", unarc_command "reports error code" rc
                end
            else
                do
                /* add filename to "done list" */
                echo file.i">>"donelistfile
                fcnt = fcnt + 1
                if delete_file = TRUE then
                    del file.i  /* delete archive from inbound directory */
                end
            end

    end

return( fcnt )

/*-------------------------------------------------------------------------*
 * IsInList                                                                *
 *                                                                         *
 * Check the "done list" file for the existence of a filename.             *
 *                                                                         *
 * Arg(1) : Name of file to test                                           *
 *                                                                         *
 *-------------------------------------------------------------------------*/

IsInList:

    testfilename = arg(1)

    parse upper var testfilename testfilename

    found = FALSE

    status = stream( donelistfile, 'c', 'open' )

    do forever
        linestr = linein( donelistfile )    /* read in a line */

        parse upper var linestr linestr

        if linestr = "" then
            leave                           /* all done reading file */

        if compare( testfilename, linestr ) = 0 then
            do
            found = TRUE                    /* file already processed */
            leave
            end
    end

    status = stream( donelistfile, 'c', 'close' )

return(found)
